@@ -214,7 +214,9 @@
     }
 
     ### check if either X or Y were unique
-    if (all(lev$Variance < ctrl$tol)) {
+    vr <- lev$Variance
+    vr[is.na(vr)] <- 0
+    if (all(vr < ctrl$tol)) {
         if (SPLITONLY) return(NULL)
         return(list(statistic = NA, p.value = NA))
     }
@@ -336,6 +338,7 @@ ctree_control <- function
     minbucket = 7L,
     minprob = 0.01,
     stump = FALSE,
+    maxvar = Inf,
     lookahead = FALSE,	### try trafo() for daugther nodes before implementing the split
     MIA = FALSE,	### DOI: 10.1016/j.patrec.2008.01.010
     nresample = 9999L,
@@ -382,7 +385,7 @@ ctree_control <- function
                                       "statistic", "p.value"),
                      logmincriterion = logmincriterion, minsplit = minsplit,
                      minbucket = minbucket, minprob = minprob,
-                     nmax = nmax, stump = stump, lookahead = lookahead,
+                     nmax = nmax, maxvar = maxvar, stump = stump, lookahead = lookahead,
                      mtry = mtry, maxdepth = maxdepth, multiway = multiway,
                      splittry = splittry, maxsurrogate = maxsurrogate,
                      numsurrogate = numsurrogate,
@@ -501,9 +504,7 @@ ctree <- function(formula, data, subset, weights, na.action = na.pass, offset, c
             yfun <- ytrafo[[response]]
             rtype <- "user-defined"
         } else {
-            rtype <- class(data[[response]])[1]
-            if (rtype == "integer") rtype <- "numeric"
-            if (rtype == "AsIs") rtype <- "numeric"
+            rtype <- .response_class(data[[response]])
         }
         response <- data[[response]]
 
@@ -521,7 +522,8 @@ ctree <- function(formula, data, subset, weights, na.action = na.pass, offset, c
                 return(matrix(sc[as.integer(response)], ncol = 1))
             },
             "numeric" = response,
-            "Surv" = .logrank_trafo(response)
+            "Surv" = .logrank_trafo(response),
+            stop("unknown response class")
         )
     } else {
         ### multivariate response
